from django.conf import settings
from django.db import models
from django.core import validators
from modelcluster.fields import ParentalManyToManyField


class SiteCommonIndex(models.Model):
    class Meta:
        abstract = True

    disp_pleine_page = models.BooleanField(
            "Afficher en pleine page",
            default=False,
            help_text="Liste les actualités en mode « pleine page ».",
    )

    disp_silo = models.BooleanField(
            "Affichage en silo",
            default=True,
            help_text="N'affiche que les actualités enfants.",
    )

    filter_motscles = ParentalManyToManyField(
            'MotCle',
            verbose_name="Filtrage sur mots clés",
            help_text=("Tout est inclut par défaut. Maintenez [Ctrl] pour en "
                       "sélectionner ou désélectionner plusieurs."),
            related_name='+',
            blank=True,
    )

    filter_productions = ParentalManyToManyField(
            'Production',
            verbose_name="Filtrage sur le type de production",
            help_text=("Tout est inclut par défaut. Maintenez [Ctrl] pour en "
                       "sélectionner ou désélectionner plusieurs."),
            related_name='+',
            blank=True,
    )

    filter_territoires = ParentalManyToManyField(
            'Territoire',
            verbose_name="Filtrage sur les territoires",
            help_text=("Tout est inclut par défaut. Maintenez [Ctrl] pour en "
                       "sélectionner ou désélectionner plusieurs."),
            related_name='+',
            blank=True,
    )

    filter_technicite = models.PositiveSmallIntegerField(
            "Technicité maximale",
            default=5,
            validators=[validators.MaxValueValidator(5)],
            help_text="Un score de 0 à 5. Tout est inclut par défaut.",
    )

    @classmethod
    def can_create_at(cls, parent):
        # Seulement un index possible sous un même parent
        has_sibling_index = cls.objects.child_of(parent).exact_type(cls).count()
        return not has_sibling_index and super().can_create_at(parent)


class RootPage():
    @classmethod
    def can_create_at(cls, parent):
        # Seulement une instance possible
        return not cls.objects.exists() and super().can_create_at(parent)


class SetSiteTheme():
    def get_template(self, request, *args, **kwargs):
        return "{}/{}.html".format(
                settings.WAGTAIL_THEME,
                self._meta.model_name,
                )
