from django.db import models
from modelcluster.models import ClusterableModel
from taggit.models import TagBase, GenericTaggedItemBase
from modelcluster.fields import ParentalKey


class MotCle(TagBase):
    class Meta:
        verbose_name = "Mot clé"
        verbose_name_plural = "Mots Clés"


class MotsClesTag(GenericTaggedItemBase):
    tag = models.ForeignKey(
            'MotCle',
            related_name='+',
            on_delete=models.CASCADE,
    )

    content_object = ParentalKey(
            'SitePage',
            on_delete=models.CASCADE,
    )


class Production(TagBase):
    class Meta:
        verbose_name = "Production"


class ProductionTag(GenericTaggedItemBase):
    tag = models.ForeignKey(
            'Production',
            related_name='+',
            on_delete=models.CASCADE,
    )

    content_object = ParentalKey(
            'SitePage',
            on_delete=models.CASCADE,
    )


class Rubrique(ClusterableModel):
    nom = models.CharField(max_length=255)

    def __str__(self):
        return self.nom


class Territoire(ClusterableModel):
    nom = models.CharField(max_length=255)

    def __str__(self):
        return self.nom


class PagesLiees(models.Model):
    pages_liees_from = ParentalKey(
            'SitePage',
            verbose_name="Page",
            related_name='pages_liees_from'
            )
    pages_liees_to = ParentalKey(
            'SitePage',
            verbose_name="Page",
            related_name='pages_liees_to'
            )

    def __str__(self):
        return "{} -> {}".format(self.pages_liees_from, self.pages_liees_to)
